/************************************************************************
* Name: 	    	Export HFS as sequence of ASCII files
* Description:	The module is applied to a harmonic fields set and
*               export each member in a seperate ASCII file.
* Authors: 	 	Christian Hellmann, LightTrans GmbH
* Keywords: 		export, parameter run, harmonic fields set
* Version: 	 	1.0 (July 16, 2010)
*************************************************************************/

using System;
using System.Collections.Generic;
using System.Drawing;

using VirtualLabAPI.Core.Common;
using VirtualLabAPI.Core.FieldRepresentations;
using VirtualLabAPI.Core.Numerics;
using VirtualLabAPI.Core.Modules;

public class VLModule : IVLModule {
    // define the base string of file names for export 
    // member ID is appended automatically
		string fileName = @"C:\temp\test_";
    // field quantity that is exported 
    // (e.g. RealPart, ImaginaryPart, Amplitude, Phase)
		FieldQuantity quantityToExport = FieldQuantity.Amplitude;

		//run method which is performed when the module is executed
    public void Run() {
      // access open document of type harmonicFieldsSet in Virtuallab 
			HarmonicFieldsSet hfsToStore = null;
			int index = -1;
			hfsToStore = (HarmonicFieldsSet)Globals.ActiveDocumentHistory.BrowseLastDocuments(DocumentFilter.HarmonicFieldsSet,
																																												out index,																																								"Select the field to export");
			if(hfsToStore == null){
				Globals.DataDisplay.LogError("No valid field selected for export.");
				return;
			}
			
      // access members of the harmonics fields set and save the files
			ASCIIParam parameters;
			for(int runSaveHFSMember = 0; runSaveHFSMember< hfsToStore.Count; runSaveHFSMember++){
					string filenameOfMember = fileName + runSaveHFSMember.ToString() + ".txt";
					parameters = new ASCIIParam(filenameOfMember, quantityToExport, false);
					ComplexAmplitude caToExport = hfsToStore[runSaveHFSMember];
					ImportExport.ExportASCII(caToExport, parameters);
			}
			
    }
}
